YouTube download helper
=======================

Drag and drop URLs from your browser to this application to download YouTube
videos using `youtube-dl`.

Requires `youtube-dl` installed in your system and in your `PATH`, as well as GNOME
terminal, or Konsole5.

To build a package you can install on your system: `python3 setup.py bdist_rpm`.
